#ifndef _GWIN_H_
#define _GWIN_H_

#include <graph.h>

class Gwin: public virtual Graph
{
    public:
	Gwin ();			// default constructor
	Gwin (int vmode);		// constructor with video mode
	
	void setscreencoord (int xa,	// set (real) screen coordinate
	    int ya, int xb, int yb);	// mapping
	    
	void setvirtualcoord (double	// set virtual screen coordinate
	    xa, double ya, double xb,	// mapping
	    double yb);
	    
	void setcolors (int f, int b);	// define drawing colors
	
	void border ();			// draw border around window
	
	void clear ();			// clear window

	void drawdot (int x, int y);	// draw one pixel, screen or 
	void drawdot (double x,		// virtual coordinates
	    double y);	
	void drawline (int x1, int y1,	// draw a line, screen or virtual
	    int x2, int y2);		// coordinates
	void drawline (double x1, 
	    double y1, double x2, 
	    double y2);
	    
	int getfgcol ();		// return foreground color
	int getbgcol ();		// return background color

    private:
    	double convertx (int x);	// screen X --> virtual X
    	int convertx (double x);	// virtual X --> screen X

	double converty (int y);	// screen Y --> virtual Y
	int converty (double y);	// virtual Y --> screen Y
    
	void error (const char *s,  	// print error and die
	    ...);
	    
	int border_present;		// do we have a border?
	int foreground_color,		// colors of this window
	    background_color;
	int whole_screen;		// does window use the whole screen?
	int x1, y1, x2, y2;		// screen coordinates
	int width, height;		// width / height in pixel units 
	double dwidth, dheight;		// width / height in virtual units
	double dx1, dy1, dx2, dy2;	// virtual coordinates
};

#endif

